==> dart_chainsql_api-1.0.3.tar.gz: lib/src/core/serialized/TypeTranslator.dart <==
import 'dart:core';
import "dart:typed_data";
import 'package:dart_chainsql_api/src/core/runtime/Value.dart';

import "./SerializedType.dart";
import "./ByteList.dart";
import "./BytesSink.dart";

import 'package:dart_chainsql_api/src/core/serialized/BinaryParser.dart';

///
/// @param <T> The SerializedType class
/// TODO, this should only really have methods that each class over-rides
///       it's currently pretty NASTY
///
abstract class TypeTranslator<T extends SerializedType> {
  T fromValue(Object object) {
    var valueType = ValueTool.typeOf(object);

    switch (valueType) {
      case Value.STRING:
        return fromString(object as String);
//      case DOUBLE:
//        return fromDouble((Double) object);
      case Value.INTEGER:
        return fromInteger(object as int);
      case Value.MAP:
        return fromMap(object as Map);
//      case BOOLEAN:
//        return fromBoolean((Boolean) object);
//      case JSON_ARRAY:
//        return fromJSONArray((JSONArray) object);
//      case JSON_OBJECT:
//        return fromJSONObject((JSONObject) object);
//      case BYTE_ARRAY:
//        return fromBytes((byte[]) object);
      case Value.UNKNOWN:
      default:
        return object as T;
    }
  }

  bool toBoolean(T obj) {
    throw new UnsupportedError("");
  }

  int toLong(T obj) {
    throw new UnsupportedError("");
  }

  int toInteger(T obj) {
    throw new UnsupportedError("");
  }

  double toDouble(T obj) {
    throw new UnsupportedError("");
  }

//  String toString(T obj) {
//
//    return obj.toString();
//  }

  T fromJSONObject(Map jsonObject) {
    throw new UnsupportedError("");
  }

  T fromJSONArray(Map jsonArray) {
    throw new UnsupportedError("");
  }

  T fromBoolean(bool aBoolean) {
    throw new UnsupportedError("");
  }

  T fromLong(int aLong) {
    throw new UnsupportedError("");
  }

  T fromInteger(int integer) {
    throw new UnsupportedError("");
  }

  T fromDouble(double aDouble) {
    throw new UnsupportedError("");
  }

  T fromMap(Map map) {
    throw new UnsupportedError("");
  }

  T fromString(String value) {
    throw new UnsupportedError("");
  }

  /**
   *
   * @param parser Parser.
   * @param hint Using a boxed integer, allowing null for no hint
   * @return return value.
   */
  T fromParser(BinaryParser parser, int hint);

//
  T fromBinaryParser(BinaryParser parser) {
    return fromParser(parser, null);
  }

//
  T fromBytes(Uint8List b) {
    return fromBinaryParser(new BinaryParser(b));
  }

//  T fromHex(String hex) {
//    return fromBytes(B16.decode(hex));
//  }

  Map toJSONObject(T obj) {
    throw new UnsupportedError("");
  }

  Map toJSONArray(T obj) {
    throw new UnsupportedError("");
  }

  Object toJSON(T obj) {
    return obj.toJSON();
  }

  void toBytesSink(T obj, BytesSink to) {
    obj.toBytesSink(to);
  }

  Uint8List toBytes(T obj) {
    BytesList to = new BytesList();
    toBytesSink(obj, to);
    return to.bytes();
  }

  String toHex(T obj) {
    BytesList to = new BytesList();
    toBytesSink(obj, to);
    return to.bytesHex();
  }
}

==> dart_chainsql_api-1.0.5.tar.gz: lib/src/core/serialized/TypeTranslator.dart <==
import 'dart:core';
import "dart:typed_data";
import 'package:dart_chainsql_api/src/core/runtime/Value.dart';

import "./SerializedType.dart";
import "./ByteList.dart";
import "./BytesSink.dart";

import 'package:dart_chainsql_api/src/core/serialized/BinaryParser.dart';

///
/// @param <T> The SerializedType class
/// TODO, this should only really have methods that each class over-rides
///       it's currently pretty NASTY
///
abstract class TypeTranslator<T extends SerializedType> {
  T fromValue(Object object) {
    var valueType = ValueTool.typeOf(object);

    switch (valueType) {
      case Value.STRING:
        return fromString(object as String);
//      case DOUBLE:
//        return fromDouble((Double) object);
      case Value.INTEGER:
        return fromInteger(object as int);
      case Value.MAP:
        return fromMap(object as Map);
//      case BOOLEAN:
//        return fromBoolean((Boolean) object);
      case Value.JSON_ARRAY:
        return fromJSONArray( object as List<Map<String, dynamic>>);
      case Value.JSON_OBJECT:
        return fromJSONObject( object);
//      case BYTE_ARRAY:
//        return fromBytes((byte[]) object);
      case Value.UNKNOWN:
      default:
        return object as T;
    }
  }

  bool toBoolean(T obj) {
    throw new UnsupportedError("");
  }

  int toLong(T obj) {
    throw new UnsupportedError("");
  }

  int toInteger(T obj) {
    throw new UnsupportedError("");
  }

  double toDouble(T obj) {
    throw new UnsupportedError("");
  }

//  String toString(T obj) {
//
//    return obj.toString();
//  }

  T fromJSONObject(Map<String, dynamic> jsonObject) {
    throw new UnsupportedError("");
  }

  T fromJSONArray( List<Map<String, dynamic>> jsonArray) {
    throw new UnsupportedError("");
  }

  T fromBoolean(bool aBoolean) {
    throw new UnsupportedError("");
  }

  T fromLong(int aLong) {
    throw new UnsupportedError("");
  }

  T fromInteger(int integer) {
    throw new UnsupportedError("");
  }

  T fromDouble(double aDouble) {
    throw new UnsupportedError("");
  }

  T fromMap(Map map) {
    throw new UnsupportedError("");
  }

  T fromString(String value) {
    throw new UnsupportedError("");
  }

  /**
   *
   * @param parser Parser.
   * @param hint Using a boxed integer, allowing null for no hint
   * @return return value.
   */
  T fromParser(BinaryParser parser, int hint);

//
  T fromBinaryParser(BinaryParser parser) {
    return fromParser(parser, null);
  }

//
  T fromBytes(Uint8List b) {
    return fromBinaryParser(new BinaryParser(b));
  }

//  T fromHex(String hex) {
//    return fromBytes(B16.decode(hex));
//  }

  Map toJSONObject(T obj) {
    throw new UnsupportedError("");
  }

  Map toJSONArray(T obj) {
    throw new UnsupportedError("");
  }

  Object toJSON(T obj) {
    return obj.toJSON();
  }

  void toBytesSink(T obj, BytesSink to) {
    obj.toBytesSink(to);
  }

  Uint8List toBytes(T obj) {
    BytesList to = new BytesList();
    toBytesSink(obj, to);
    return to.bytes();
  }

  String toHex(T obj) {
    BytesList to = new BytesList();
    toBytesSink(obj, to);
    return to.bytesHex();
  }
}
